@@ -20,7 +20,8 @@ sp_layer_build <- function(layer, plot) {
     stop("layer does not have embedded subplots")
   }
 
-  minimal <- ("ggplot2" %:::% "plot_clone")(plot)
+  f <- get("plot_clone", envir = asNamespace("ggplot2"))
+  minimal <- f(plot)
   minimal$data <- ggplot2::waiver()
   minimal$scales$scales[which_x(minimal$scales$scales)] <- NULL
   minimal$scales$scales[which_y(minimal$scales$scales)] <- NULL
@@ -60,7 +61,8 @@ sp_layer_build <- function(layer, plot) {
   minor$plot$facet <- ggplot2::facet_null()
   minor$plot$scales$scales <- scales
   
-  ("ggplot2" %:::% "set_last_plot")(plot)
+  f <- get("set_last_plot", envir = asNamespace("ggplot2"))
+  f(plot)
   
   minor
 }
